.. module:: bana.OpenMaya.MGlobal

.. _openmaya_mglobal:

OpenMaya.MGlobal
================

.. autosummary::
   :nosignatures:

   ~MGlobal.bnIsValidName
   ~MGlobal.bnIsValidFullName
   ~MGlobal.bnIsValidPath
   ~MGlobal.bnIsValidFullPath
   ~MGlobal.bnMakeMatchNameFunction
   ~MGlobal.bnMakeMatchFullNameFunction
   ~MGlobal.bnMakeMatchPathFunction
   ~MGlobal.bnMakeMatchFullPathFunction
   ~MGlobal.bnMatchName
   ~MGlobal.bnMatchFullName
   ~MGlobal.bnMatchPath
   ~MGlobal.bnMatchFullPath


----

.. automethod:: MGlobal.bnIsValidName

----

.. automethod:: MGlobal.bnIsValidFullName

----

.. automethod:: MGlobal.bnIsValidPath

----

.. automethod:: MGlobal.bnIsValidFullPath

----

.. automethod:: MGlobal.bnMakeMatchNameFunction

----

.. automethod:: MGlobal.bnMakeMatchFullNameFunction

----

.. automethod:: MGlobal.bnMakeMatchPathFunction

----

.. automethod:: MGlobal.bnMakeMatchFullPathFunction

----

.. automethod:: MGlobal.bnMatchName

----

.. automethod:: MGlobal.bnMatchFullName

----

.. automethod:: MGlobal.bnMatchPath

----

.. automethod:: MGlobal.bnMatchFullPath
